.. indicfortune documentation master file, created by
   sphinx-quickstart on Tue Sep 17 02:25:48 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

indicfortune
============

A fortune cookie database and  generator for indic languages.

Usage
-----

 >>> from indicfortune getInstance
 >>> f = getInstance()
 >>> f.fortune('chanakya')
 u' The beauty of a cuckoo is in its notes, that
 of a woman\n in her unalloyed devotion to her husband, that of an\n
 ugly person in his scholarship, and that of an ascetic\n in his
 forgiveness.\n'

API reference
------------

.. automodule:: indicfortune.core
   :members:

Available fortune databases
----------------------------

* chanakya
* malayalam_proverbs
* thirukkural


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
